@@ -569,9 +569,15 @@ static REAL8 XLALSimInspiralChirpLength(
 		case LAL_SIM_INSPIRAL_TIDAL_ORDER_6PN:
 			t12 = XLALSimInspiralTaylorT2Timing_12PNTidalCoeff(eta,chi1,lambda1)
 		    	+ XLALSimInspiralTaylorT2Timing_12PNTidalCoeff(eta,chi2,lambda2);
+#if __GNUC__ >= 7
+			__attribute__ ((fallthrough));
+#endif
 		case LAL_SIM_INSPIRAL_TIDAL_ORDER_5PN:
 			t10 = XLALSimInspiralTaylorT2Timing_10PNTidalCoeff(chi1,lambda1)
 		    	+ XLALSimInspiralTaylorT2Timing_10PNTidalCoeff(chi2,lambda2);
+#if __GNUC__ >= 7
+			__attribute__ ((fallthrough));
+#endif
 		case LAL_SIM_INSPIRAL_TIDAL_ORDER_0PN:
 			break;
 		default:
@@ -585,17 +591,35 @@ static REAL8 XLALSimInspiralChirpLength(
 		case 0:
 		case 1:
 			t2 = 0.;
+#if __GNUC__ >= 7
+			__attribute__ ((fallthrough));
+#endif
 		case 2:
 			t3 = 0.;
+#if __GNUC__ >= 7
+			__attribute__ ((fallthrough));
+#endif
 		case 3:
 			t4 = 0.;
+#if __GNUC__ >= 7
+			__attribute__ ((fallthrough));
+#endif
 		case 4:
 			t5 = 0.;
+#if __GNUC__ >= 7
+			__attribute__ ((fallthrough));
+#endif
 		case 5:
 			t6 = 0.;
 			t6l = 0.;
+#if __GNUC__ >= 7
+			__attribute__ ((fallthrough));
+#endif
 		case 6:
 			t7 = 0.;
+#if __GNUC__ >= 7
+			__attribute__ ((fallthrough));
+#endif
 		case 7:
         case -1: // Use the max PN order, move if higher orders implemented
 			break;
@@ -690,11 +714,17 @@ static int XLALSimInspiralTaylorT3Setup(
       ak->fta12 = XLALSimInspiralTaylorT3Frequency_12PNTidalCoeff(
           eta, chi1, lambda1)
           + XLALSimInspiralTaylorT3Frequency_12PNTidalCoeff(eta,chi2,lambda2);
+#if __GNUC__ >= 7
+      __attribute__ ((fallthrough));
+#endif
     case LAL_SIM_INSPIRAL_TIDAL_ORDER_5PN:
       ak->pta10 = XLALSimInspiralTaylorT3Phasing_10PNTidalCoeff(chi1,lambda1)
                 + XLALSimInspiralTaylorT3Phasing_10PNTidalCoeff(chi2,lambda2);
       ak->fta10 = XLALSimInspiralTaylorT3Frequency_10PNTidalCoeff(chi1,lambda1)
                 + XLALSimInspiralTaylorT3Frequency_10PNTidalCoeff(chi2,lambda2);
+#if __GNUC__ >= 7
+      __attribute__ ((fallthrough));
+#endif
     case LAL_SIM_INSPIRAL_TIDAL_ORDER_0PN:
       break;
     default:
