@@ -72,9 +72,18 @@ static LALUnit strainSquaredPerHertzUnit = { 0, { 0, 0, 1, 0, 0, 2, 0}, { 0, 0,
 /* prefix for noise psd files provided by LIGO-P1200087 */
 #define P1200087 "LIGO-P1200087-v18-"
 
+/* prefix for noise psd files provided by LIGO-P1600143 */
+#define P1600143 "LIGO-P1600143-v18-"
+
 /* prefix for noise psd files provided by LIGO-T1600593 */
 #define T1600593 "LIGO-T1600593-v1-"
 
+/* prefix for noise psd files provided by LIGO-T1800042 */
+#define T1800042 "LIGO-T1800042-v5-"
+
+/* prefix for noise psd files provided by LIGO-T1800044 */
+#define T1800044 "LIGO-T1800044-v5-"
+
 /**
  * @addtogroup LALSimNoisePSD_c
  * @brief Routines to compute noise power spectral densities for
@@ -1393,6 +1402,65 @@ int XLALSimNoisePSDAdVBNSOptimizedSensitivityP1200087(
 
 /** @} */
 
+/**
+ * @name Noise PSDs from LIGO-P1600143
+ * @{
+ */
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to Cosmic Explorer in LIGO-P1600143.
+ */
+int XLALSimNoisePSDCosmicExplorerP1600143(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		P1600143 "CE.txt");
+}
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to Cosmic Explorer (pessimistic) in LIGO-P1600143.
+ */
+int XLALSimNoisePSDCosmicExplorerPessimisticP1600143(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		P1600143 "CE_Pessimistic.txt");
+}
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to Cosmic Explorer (wideband) in LIGO-P1600143.
+ */
+int XLALSimNoisePSDCosmicExplorerWidebandP1600143(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		P1600143 "CE_Wideband.txt");
+}
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to Einstein Telescope in LIGO-P1600143.
+ */
+int XLALSimNoisePSDEinsteinTelescopeP1600143(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		P1600143 "ET_D.txt");
+}
+
+/** @} */
+
 /**
  * @name Noise PSDs from LIGO-
  * @{
@@ -1465,6 +1533,47 @@ int XLALSimNoisePSDKAGRADesignSensitivityT1600593(
 
 /** @} */
 
+/**
+ * @name Noise PSDs from LIGO-T1800042
+ * @{
+ */
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to the A+ configuration design sensitivity scenario in LIGO-T1800042.
+ */
+int XLALSimNoisePSDaLIGOAPlusDesignSensitivityT1800042(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		T1800042 "aLIGO_APLUS.txt");
+}
+
+/** @} */
+
+/**
+ * @name Noise PSDs from LIGO-T1800044
+ * @{
+ */
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to an updated aLIGO configuration design sensitivity scenario in 
+ * LIGO-T1800044.
+ */
+int XLALSimNoisePSDaLIGOaLIGODesignSensitivityT1800044(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		T1800044 "aLIGO_DESIGN.txt");
+}
+
+/** @} */
+
 /** @} */
 
 /*
