@@ -29,7 +29,7 @@
 #include <lal/LALSimInspiral.h>
 #include <lal/LALSimIMR.h>
 #include <lal/XLALError.h>
-#include <lal/LALAdaptiveRungeKutta4.h>
+#include <lal/LALAdaptiveRungeKuttaIntegrator.h>
 #include <lal/LALSimInspiralWaveformParams.h>
 
 /* internal storage is in SI units! */
@@ -88,6 +88,9 @@ const char * usage =
 "                             SEOBNRv1\n"
 "                             SEOBNRv2\n"
 "                             SEOBNRv3\n"
+"                             SEOBNRv4\n"
+"                             SEOBNRv2T\n"
+"                             SEOBNRv4T\n"
 "                             SpinTaylorT4\n"
 "                             SpinTaylorT2\n"
 "                             PhenSpinTaylor\n"
@@ -138,6 +141,16 @@ const char * usage =
 "                           (~128-2560 for NS, 0 for BH) (default 0)\n"
 "--tidal-lambda2 L2         (tidal deformability of mass 2) / (mass of body 2)^5\n"
 "                           (~128-2560 for NS, 0 for BH) (default 0)\n"
+"--tidal-lambda-octu1 L31         (octupolar tidal deformability of mass 1) / (mass of body 1)^7\n"
+"                           (0 for BH) (default 0)\n"
+"--tidal-lambda-octu2 L32         (octupolar tidal deformability of mass 2) / (mass of body 2)^7\n"
+"                           (0 for BH) (default 0)\n"
+"--tidal-quadfmode1 W21      dimensionless quadrupolar f-mode angular frequency of mass 1, normalized to mass 1\n"
+"--tidal-quadfmode2 W22      dimensionless quadrupolar f-mode angular frequency of mass 2, normalized to mass 2\n"
+"--tidal-octufmode1 W31      dimensionless octupolar f-mode angular frequency of mass 1, normalized to mass 1\n"
+"--tidal-octufmode2 W32      dimensionless octupolar f-mode angular frequency of mass 2, normalized to mass 2\n"
+"--quad-mon1 kappa1          dimensionless quadrupole-monopole parameter of mass 1, value 1 for a black hole\n"
+"--quad-mon2 kappa2          dimensionless quadrupole-monopole parameter of mass 2, value 1 for a black hole\n"
 "--spin-order ORD           Twice PN order of spin effects\n"
 "                           (default ORD=-1 <==> All spin effects)\n"
 "--tidal-order ORD          Twice PN order of tidal effects\n"
@@ -205,6 +218,9 @@ static GSParams *parse_args(ssize_t argc, char **argv) {
     params->meanPerAno = 0.;
     XLALSimInspiralWaveformParamsInsertTidalLambda1(params->params, 0.);
     XLALSimInspiralWaveformParamsInsertTidalLambda2(params->params, 0.);
+    /* Note: given a LALDict, SEOBNRv2T/v4T will check wether other parameters ( TidalOctupolarLambda, TidalQuadrupolarFMode, TidalOctupolarFMode, dQuadMon) are present in the LALDict */
+    /* If present, this value is looked up and used, if absent, the parameter is computed from quadrupolar lambda through universal relations */
+    /* We therefore do not Insert default values for these parameters, they will be inserted in LALDict only if specified on the commandline */
     strncpy(params->outname, "simulation.dat", 256); /* output to this file */
     params->verbose = 0; /* No verbosity */
 
@@ -265,9 +281,25 @@ static GSParams *parse_args(ssize_t argc, char **argv) {
         } else if (strcmp(argv[i], "--spin2z") == 0) {
             params->s2z = atof(argv[++i]);
         } else if (strcmp(argv[i], "--tidal-lambda1") == 0) {
-	    XLALSimInspiralWaveformParamsInsertTidalLambda1(params->params, atoi(argv[++i]));
+	    XLALSimInspiralWaveformParamsInsertTidalLambda1(params->params, atof(argv[++i]));
         } else if (strcmp(argv[i], "--tidal-lambda2") == 0) {
-	    XLALSimInspiralWaveformParamsInsertTidalLambda2(params->params, atoi(argv[++i]));
+	    XLALSimInspiralWaveformParamsInsertTidalLambda2(params->params, atof(argv[++i]));
+        } else if (strcmp(argv[i], "--tidal-lambda-octu1") == 0) {
+        XLALSimInspiralWaveformParamsInsertTidalOctupolarLambda1(params->params, atof(argv[++i]));
+        } else if (strcmp(argv[i], "--tidal-lambda-octu2") == 0) {
+        XLALSimInspiralWaveformParamsInsertTidalOctupolarLambda2(params->params, atof(argv[++i]));
+        } else if (strcmp(argv[i], "--tidal-quadfmode1") == 0) {
+        XLALSimInspiralWaveformParamsInsertTidalQuadrupolarFMode1(params->params, atof(argv[++i]));
+        } else if (strcmp(argv[i], "--tidal-quadfmode2") == 0) {
+        XLALSimInspiralWaveformParamsInsertTidalQuadrupolarFMode2(params->params, atof(argv[++i]));
+        } else if (strcmp(argv[i], "--tidal-octufmode1") == 0) {
+        XLALSimInspiralWaveformParamsInsertTidalOctupolarFMode1(params->params, atof(argv[++i]));
+        } else if (strcmp(argv[i], "--tidal-octufmode2") == 0) {
+        XLALSimInspiralWaveformParamsInsertTidalOctupolarFMode2(params->params, atof(argv[++i]));
+        } else if (strcmp(argv[i], "--quad-mon1") == 0) {
+        XLALSimInspiralWaveformParamsInsertdQuadMon1(params->params, atof(argv[++i]) - 1.); /* dQuadMon is kappa-1 */
+        } else if (strcmp(argv[i], "--quad-mon2") == 0) {
+        XLALSimInspiralWaveformParamsInsertdQuadMon2(params->params, atof(argv[++i]) - 1.); /* dQuadMon is kappa-1 */
         } else if (strcmp(argv[i], "--spin-order") == 0) {
 	    XLALSimInspiralWaveformParamsInsertPNSpinOrder(params->params, atoi(argv[++i]));
         } else if (strcmp(argv[i], "--tidal-order") == 0) {
@@ -409,7 +441,7 @@ static int dump_TD(FILE *f, REAL8TimeSeries *hplus, REAL8TimeSeries *hcross) {
 
     fprintf(f, "# t hplus hcross\n");
     for (i=0; i < hplus->data->length; i++)
-        fprintf(f, "%.16e %.16e %.16e\n", t0 + i * hplus->deltaT, 
+        fprintf(f, "%.16e %.16e %.16e\n", t0 + i * hplus->deltaT,
                 hplus->data->data[i], hcross->data->data[i]);
     return 0;
 }
@@ -455,7 +487,7 @@ int main (int argc , char **argv) {
     REAL8TimeSeries *hplus = NULL;
     REAL8TimeSeries *hcross = NULL;
     GSParams *params;
-	
+
     /* set us up to fail hard */
     XLALSetErrorHandler(XLALAbortErrorHandler);
 
@@ -488,7 +520,7 @@ int main (int argc , char **argv) {
             XLALPrintError("Error: domain must be either TD or FD\n");
     }
     if (params->verbose)
-        XLALPrintInfo("Generation took %.0f seconds\n", 
+        XLALPrintInfo("Generation took %.0f seconds\n",
                 difftime(time(NULL), start_time));
     if (((params->domain == LAL_SIM_DOMAIN_FREQUENCY) && (!hptilde || !hctilde)) ||
         ((params->domain == LAL_SIM_DOMAIN_TIME) && (!hplus || !hcross))) {
